@@ -10,19 +10,19 @@ Cstack Main Application Configuration
 from pathlib import Path
 from tomllib import loads
 from fastapi import FastAPI
-from fastapi.staticfiles import StaticFiles
 from .api import API
+from .spa import SinglePageApplication
 
 PROJECT = loads(Path("pyproject.toml").read_text("utf-8"))
 
 
 def Application(*, api: API, view_dist: str = "view/dist"):
     api = api
-    view = StaticFiles(
-        directory=f"{PROJECT['tool']['poetry']['name']}/{view_dist}", html=True
+    view = SinglePageApplication(
+        directory=f"{PROJECT['tool']['poetry']['name']}/{view_dist}"
     )
 
     app = FastAPI()
     app.mount("/api", api.app, "api")
-    app.mount("/", view, "frontend")
+    app.mount("/", view, "view")
     return app
